@@ -1,7 +1,7 @@
 //! Global constants, such as compiler version used, algorithms, compression and filters supported and others
-pub const COMPILATION_DATE: &str = "Nov 24 2020";
-pub const COMPILATION_TIME: &str = "22:31:44";
-pub const VERSION: &str = "0.2.7";
+pub const COMPILATION_DATE: &str = "Jan 03 2021";
+pub const COMPILATION_TIME: &str = "20:41:49";
+pub const VERSION: &str = "0.4.0";
 pub const ALGORITHMS: [&str; 10] = ["alpha","multiplicative","source_over","destination_over","mask_top","first_top","first_bottom","disjoint_over","disjoint_under","disjoint_debug"];
 pub const COMPILER: &str = "rustc";
 pub const COMPILER_VERSION: &str = "1.40.0";
